@@ -3,7 +3,7 @@ package Padre::Plugin::Moose::Program;
 use Moose;
 use namespace::clean;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 with 'Padre::Plugin::Moose::Role::CanGenerateCode';
 with 'Padre::Plugin::Moose::Role::CanProvideHelp';
@@ -12,23 +12,23 @@ has 'roles'   => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
 has 'classes' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
 
 sub generate_moose_code {
-	my $self             = shift;
-	my $code_gen_options = shift;
+	my $self    = shift;
+	my $options = shift;
 
 	my $code = '';
 
 	# Generate roles
 	for my $role ( @{ $self->roles } ) {
-		$code .= $role->generate_moose_code($code_gen_options);
+		$code .= $role->generate_moose_code($options);
 	}
 
 	# Generate classes
 	for my $class ( @{ $self->classes } ) {
-		$code .= $class->generate_moose_code($code_gen_options);
+		$code .= $class->generate_moose_code($options);
 	}
 
 	# Generate sample usage code
-	if ( $code_gen_options->{sample_code} ) {
+	if ( $options->{sample_code} ) {
 		$code .= "\npackage main;\n";
 		my $count = 1;
 		for my $class ( @{ $self->classes } ) {
@@ -46,23 +46,23 @@ sub generate_moose_code {
 
 # Generate Mouse code!
 sub generate_mouse_code {
-	my $self             = shift;
-	my $code_gen_options = shift;
+	my $self    = shift;
+	my $options = shift;
 
 	my $code = '';
 
 	# Generate roles
 	for my $role ( @{ $self->roles } ) {
-		$code .= $role->generate_mouse_code($code_gen_options);
+		$code .= $role->generate_mouse_code($options);
 	}
 
 	# Generate classes
 	for my $class ( @{ $self->classes } ) {
-		$code .= $class->generate_mouse_code($code_gen_options);
+		$code .= $class->generate_mouse_code($options);
 	}
 
 	# Generate sample usage code
-	if ( $code_gen_options->{sample_code} ) {
+	if ( $options->{sample_code} ) {
 		$code .= "\npackage main;\n";
 		my $count = 1;
 		for my $class ( @{ $self->classes } ) {
@@ -75,23 +75,23 @@ sub generate_mouse_code {
 }
 
 sub generate_moosex_declare_code {
-	my $self             = shift;
-	my $code_gen_options = shift;
+	my $self    = shift;
+	my $options = shift;
 
 	my $code = '';
 
 	# Generate roles
 	for my $role ( @{ $self->roles } ) {
-		$code .= $role->generate_moosex_declare_code($code_gen_options);
+		$code .= $role->generate_moosex_declare_code($options);
 	}
 
 	# Generate classes
 	for my $class ( @{ $self->classes } ) {
-		$code .= $class->generate_moosex_declare_code($code_gen_options);
+		$code .= $class->generate_moosex_declare_code($options);
 	}
 
 	# Generate sample usage code
-	if ( $code_gen_options->{sample_code} ) {
+	if ( $options->{sample_code} ) {
 		$code .= "\npackage main;\n";
 		my $count = 1;
 		for my $class ( @{ $self->classes } ) {
